<?php

namespace Elementor;

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}


/**
 *
 * swp-shop elementor Contact widget.
 *
 * @since 1.0
 */
class Swp_Shop_Slider extends Widget_Base
{

    public function get_name()
    {
        return 'swp-shop-slider';
    }

    public function get_title()
    {
        return esc_html__('Slider', 'swp-shop');
    }

    public function get_icon()
    {
        return 'eicon-post-list';
    }

    public function get_categories()
    {
        return ['swp-shop'];
    }

    protected function register_controls()
    {

        // general settings
        $this->start_controls_section(
            'ele_style_one_settings',
            [
                'label' => esc_html__('General Settings', 'swp-shop'),
            ]
        );


        $this->add_control(
            'style',
            [
                'label'   => esc_html__('Select Style', 'swp-shop'),
                'type'    => Controls_Manager::SELECT2,
                'options' => array(
                    'style-1' => esc_html__('Style 1', 'swp-shop'),
                    'style-2'  => esc_html__('Style 2', 'swp-shop'),
                    'style-3'  => esc_html__('Style 3', 'swp-shop'),
                    'style-4'  => esc_html__('Style 4', 'swp-shop'),
                    'style-5'  => esc_html__('Style 5', 'swp-shop'),
                ),
                'default' => 'style-1'

            ]
        );

        $this->add_control(
            'ppr',
            [
                'label'   => esc_html__('Amount of post to display', 'swp-shop'),
                'type'    => Controls_Manager::TEXT,
                'default' => 6
            ]
        );


        $this->end_controls_section(); // End general settings

        $this->start_controls_section(
            'Post_filter_settings',
            [
                'label' => esc_html__('Post Options', 'swp-shop'),
            ]
        );


        $this->add_control(
            'select_cat',
            [
                'label'    => esc_html__('Select Category', 'swp-shop'),
                'type'     => Controls_Manager::SELECT2,
                'description' => esc_html__('Keep Blank To Display All Categories Job', 'swp-shop'),
                'multiple' => true,
                'options'  => swp_shop_post_category(),

            ]
        );


        $this->add_control(
            'exclude_cat',
            [
                'label'    => esc_html__('Exclude Category', 'swp-shop'),
                'type'     => Controls_Manager::SELECT2,
                'multiple' => true,
                'options'  => swp_shop_post_category(),
            ]
        );

        $this->add_control(
            'orderby',
            [
                'label'   => esc_html__('Order by', 'swp-shop'),
                'type'    => Controls_Manager::SELECT2,
                'options' => array(
                    'author' => esc_html__('Author', 'swp-shop'),
                    'title'  => esc_html__('Title', 'swp-shop'),
                    'date'   => esc_html__('Date', 'swp-shop'),
                    'rand'   => esc_html__('Random', 'swp-shop'),
                ),
                'default' => 'date'

            ]
        );

        $this->add_control(
            'order',
            [
                'label'   => esc_html__('Order', 'swp-shop'),
                'type'    => Controls_Manager::SELECT2,
                'options' => array(
                    'desc' => esc_html__('DESC', 'swp-shop'),
                    'asc'  => esc_html__('ASC', 'swp-shop'),
                ),
                'default' => 'desc'

            ]
        );


        $this->end_controls_section(); // End Filter

        //title settings
        $this->start_controls_section(
            'title_settings',
            [
                'label' => esc_html__('Title Settings', 'swp-shop'),
            ]
        );

        $this->add_control(
            'dtitle',
            [
                'label'   => esc_html__('Display', 'swp-shop'),
                'type'    => Controls_Manager::SELECT2,
                'options' => array(
                    'full' => esc_html__('Full Title', 'swp-shop'),
                    'excerpt'  => esc_html__('Excerpt', 'swp-shop'),
                ),
                'default' => 'full'

            ]
        );

        $this->add_control(
            'title_excerpt_length',
            [
                'label'   => esc_html__('Title Excerpt Length', 'swp-shop'),
                'type'    => Controls_Manager::TEXT,
                'default' => 3,
                'condition' => [
                    'dtitle' => 'excerpt'
                ]
            ]
        );

        $this->add_control(
            'titltag',
            [
                'label'   => esc_html__('Title Tag', 'swp-shop'),
                'type'    => Controls_Manager::SELECT,
                'options' => array(
                    'h1' => 'H1',
                    'h2' => 'H2',
                    'h3' => 'H3',
                    'h4' => 'H4',
                    'h5' => 'H5',
                    'h6' => 'H6',
                ),
                'default' => 'h5'

            ]
        );

        $this->end_controls_section(); // End title


        // slider options 
        $this->start_controls_section(
            'slider_settings',
            [
                'label' => esc_html__('Slider Settings', 'swp-shop'),
                'condition' => [
                    'style' => ['style-1', 'style-2', 'style-3', 'style-4', 'style-5']
                ]
            ]
        );

        $this->add_control(
            'loop',
            [
                'label' => esc_html__('AutoPlay', 'swp-shop'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'swp-shop'),
                'label_off' => esc_html__('No', 'swp-shop'),
                'return_value' => 'yes',
                'default' => 'yes',
                'condition' => [
                    'style' => ['style-1', 'style-2', 'style-5']
                ]
            ]
        );


        $this->add_control(
            'enable_nav',
            [
                'label' => esc_html__('Display Nav', 'swp-shop'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'swp-shop'),
                'label_off' => esc_html__('No', 'swp-shop'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'nav_left_icon',
            [
                'label' => esc_html__('Nav Left Icon', 'swp-shop'),
                'type' => \Elementor\Controls_Manager::ICONS,
                'condition' => [
                    'enable_nav' => 'yes'
                ],
                'default' => [
                    'value' => 'fa fa-angle-left',
                    'library' => 'solid',
                ],
            ]
        );

        $this->add_control(
            'nav_right_icon',
            [
                'label' => esc_html__('Nav Right Icon', 'swp-shop'),
                'type' => \Elementor\Controls_Manager::ICONS,
                'condition' => [
                    'enable_nav' => 'yes'
                ],
                'default' => [
                    'value' => 'fa fa-angle-right',
                    'library' => 'solid',
                ],
            ]
        );

        $this->add_control(
            'enable_dots',
            [
                'label' => esc_html__('Display Dots', 'swp-shop'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'swp-shop'),
                'label_off' => esc_html__('No', 'swp-shop'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );


        $this->add_control(
            'smart_speed',
            [
                'label' => __('Smart Speed', 'swp-shop'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['count'],

                'range' => [
                    'count' => [
                        'min' => 0,
                        'max' => 10000,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'unit' => 'count',
                    'size' => 700,
                ],
            ]
        );


        $this->add_control(
            'items',
            [
                'label' => __('Slide Items', 'swp-shop'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['count'],
                'range' => [
                    'count' => [
                        'min' => 1,
                        'max' => 10,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'unit' => 'count',
                    'size' => 3,
                ],
                'condition' => [
                    'style' => ['style-1', 'style-2', 'style-5']
                ]
            ],
        );

        $this->add_control(
            'margin',
            [
                'label' => __('Margin', 'swp-shop'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['count'],
                'range' => [
                    'count' => [
                        'min' => 1,
                        'max' => 200,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'unit' => 'count',
                    'size' => 30,
                ],
            ]
        );

        $this->end_controls_section(); // End title


        // other 
        $this->start_controls_section(
            'other_settings',
            [
                'label' => esc_html__('Other Settings', 'swp-shop'),
            ]
        );

        $this->add_control(
            'content_excerpt_length',
            [
                'label'   => esc_html__('Content Excerpt Length', 'swp-shop'),
                'type'    => Controls_Manager::TEXT,
                'default' => 15,
                'condition' => [
                    'style' => 'style-4'
                ]
            ]
        );

        $this->add_control(
            'open-url',
            [
                'label'   => esc_html__('Where Open Product?', 'swp-shop'),
                'type'    => Controls_Manager::SELECT,
                'options' => array(
                    'same-window' => esc_html__('Same Window', 'swp-shop'),
                    'new-window' => esc_html__('New Window', 'swp-shop'),
                ),
                'default' => 'same-window'

            ]
        );

        $this->end_controls_section(); // End sub title


        //title style
        $this->start_controls_section(
            'title_style',
            [
                'label' => esc_html__('Title Style', 'swp-shop'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => esc_html__('Title Color', 'swp-shop'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-shop-single-inner .content-box .inner-title a' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'title_hover_color',
            [
                'label' => esc_html__('Title Hover Color', 'swp-shop'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-shop-single-inner .content-box .inner-title a:hover' => 'color: {{VALUE}}',
                ],
            ]
        );

        //title typography
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'           => 'title_typography',
                'label'          => esc_html__('Title Typography', 'swp-shop'),
                'selector'       => '{{WRAPPER}} .swp-shop-single-inner .content-box .inner-title a',
            ]
        );

        $this->end_controls_section();

        //price style
        $this->start_controls_section(
            'price_style',
            [
                'label' => esc_html__('Price Style', 'swp-shop'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'price_color',
            [
                'label' => esc_html__('Price Color', 'swp-shop'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .price,{{WRAPPER}} .woocommerce-Price-amount.amount' => 'color: {{VALUE}}',
                ],
            ]
        );

        //Price typography
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'           => 'price_typography',
                'label'          => esc_html__('Price Typography', 'swp-shop'),
                'selector'       => '{{WRAPPER}} .price,{{WRAPPER}} .woocommerce-Price-amount.amount',
            ]
        );

        $this->end_controls_section();

        //Other style
        $this->start_controls_section(
            'other_style',
            [
                'label' => esc_html__('Other ', 'swp-shop'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'badge_color',
            [
                'label' => esc_html__('Badge Color', 'swp-shop'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-badge-btn' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'badge_bg_color',
            [
                'label' => esc_html__('Badge Background Color', 'swp-shop'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-badge-btn' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'icon_color',
            [
                'label' => esc_html__('Icon Color', 'swp-shop'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-readmore-arrow' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'style' => ['style-1', 'style-2', 'style-3', 'style-4', 'style-5']
                ]
            ]
        );

        $this->add_control(
            'rating_color',
            [
                'label' => esc_html__('Rating Color', 'swp-shop'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-shop-single-inner .star-rating span:before,{{WRAPPER}} .swp-shop-single-inner .star-rating::before' => 'color: {{VALUE}} !important',
                ],
                'condition' => [
                    'style' =>  ['style-2', 'style-3', 'style-4', 'style-5']
                ]
            ]
        );

        $this->add_control(
            'section_bg_color',
            [
                'label' => esc_html__('Background Color', 'swp-shop'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-shop-single-inner.style-9' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'style' =>  ['style-2', 'style-3', 'style-4', 'style-5']
                ]
            ]
        );


        $this->end_controls_section();

        //slider  style
        $this->start_controls_section(
            'filter_button_style',
            [
                'label' => esc_html__('Slider Style', 'swp-shop'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'slider_arrow_color',
            [
                'label' => esc_html__('Arrow Color', 'swp-shop'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slider-control-base .owl-dots button:after' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .slider-control-base .owl-dots button' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'slider_nav_color',
            [
                'label' => esc_html__('Nav Color', 'swp-shop'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slider-control-base .owl-nav button' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .owl-nav button' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'slider_nav_bg',
            [
                'label' => esc_html__('Nav Background Color', 'swp-shop'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slider-control-base .owl-nav button' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'slider_nav_hover_bg',
            [
                'label' => esc_html__('Nav Hover Background Color', 'swp-shop'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slider-control-base .owl-nav button:hover' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .owl-nav button:hover' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();
    }

    protected function render()
    {

        $settings = $this->get_settings();

        $paged = (get_query_var('page')) ? absint(get_query_var('page')) : 1;

        $args  = array(
            'post_type'           => 'product',
            'post_status'         => 'publish',
            'ignore_sticky_posts' => 1,
            'posts_per_page'      => $settings['ppr'],
            'paged' => $paged,
        );

        $args['orderby'] = $settings['orderby'];
        $args['order']   = $settings['order'];

        if (!empty($_GET['product_cat']) && -1 != $_GET['product_cat']) {
            $args['tax_query'][] = array(
                'taxonomy' => 'product_cat',
                'field'    => 'slug',
                'terms'    =>  sanitize_text_field($_GET['product_cat'])
            );
        } elseif (!empty($settings['select_cat'])) {
            $args['tax_query'][] = array(
                'taxonomy' => 'product_cat',
                'field'    => 'id',
                'terms'    => array_values($settings['select_cat'])
            );
        }


        if (!empty($settings['exclude_cat'])) {
            $args['tax_query'][] = array(
                'taxonomy' => 'product_cat',
                'field'    => 'id',
                'terms'    => array_values($settings['exclude_cat']),
                'operator' => 'NOT IN'
            );
        }
        $swp_shop_posts_query = new \WP_Query($args);

        include swp_shop_get_template('slider-one.php');
        include swp_shop_get_template('slider-two.php');
        include swp_shop_get_template('slider-three.php');
        include swp_shop_get_template('slider-four.php');
        include swp_shop_get_template('slider-five.php');
    }
}

plugin::instance()->widgets_manager->register(new Swp_Shop_Slider());
