<?php

namespace Elementor;

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}


/**
 *
 * swp-shop elementor Contact widget.
 *
 * @since 1.0
 */
class Swp_Shop_Tab extends Widget_Base
{

    public function get_name()
    {
        return 'swp-shop-tab';
    }

    public function get_title()
    {
        return esc_html__('Tab Style', 'swp-shop');
    }

    public function get_icon()
    {
        return 'eicon-post-list';
    }

    public function get_categories()
    {
        return ['swp-shop'];
    }

    protected function register_controls()
    {

        // general settings
        $this->start_controls_section(
            'ele_style_one_settings',
            [
                'label' => esc_html__('General Settings', 'swp-shop'),
            ]
        );


        $this->add_control(
            'style',
            [
                'label'   => esc_html__('Select Style', 'swp-shop'),
                'type'    => Controls_Manager::SELECT2,
                'options' => array(
                    'style-1' => esc_html__('Style 1', 'swp-shop'),
                    'style-2'  => esc_html__('Style 2', 'swp-shop'),
                ),
                'default' => 'style-1'

            ]
        );

        $this->add_control(
            'ppr',
            [
                'label'   => esc_html__('Amount of post to display', 'swp-shop'),
                'type'    => Controls_Manager::TEXT,
                'default' => 6
            ]
        );


        $this->end_controls_section(); // End general settings

        $this->start_controls_section(
            'Post_filter_settings',
            [
                'label' => esc_html__('Post Options', 'swp-shop'),
            ]
        );


        $this->add_control(
            'select_cat',
            [
                'label'    => esc_html__('Select Category', 'swp-shop'),
                'type'     => Controls_Manager::SELECT2,
                'description' => esc_html__('Keep Blank To Display All Categories Job', 'swp-shop'),
                'multiple' => true,
                'options'  => swp_shop_post_category(),

            ]
        );


        $this->add_control(
            'exclude_cat',
            [
                'label'    => esc_html__('Exclude Category', 'swp-shop'),
                'type'     => Controls_Manager::SELECT2,
                'multiple' => true,
                'options'  => swp_shop_post_category(),
            ]
        );

        $this->add_control(
            'orderby',
            [
                'label'   => esc_html__('Order by', 'swp-shop'),
                'type'    => Controls_Manager::SELECT2,
                'options' => array(
                    'author' => esc_html__('Author', 'swp-shop'),
                    'title'  => esc_html__('Title', 'swp-shop'),
                    'date'   => esc_html__('Date', 'swp-shop'),
                    'rand'   => esc_html__('Random', 'swp-shop'),
                ),
                'default' => 'date'

            ]
        );

        $this->add_control(
            'order',
            [
                'label'   => esc_html__('Order', 'swp-shop'),
                'type'    => Controls_Manager::SELECT2,
                'options' => array(
                    'desc' => esc_html__('DESC', 'swp-shop'),
                    'asc'  => esc_html__('ASC', 'swp-shop'),
                ),
                'default' => 'desc'

            ]
        );


        $this->end_controls_section(); // End Filter

        //title settings
        $this->start_controls_section(
            'title_settings',
            [
                'label' => esc_html__('Title Settings', 'swp-shop'),
            ]
        );

        $this->add_control(
            'dtitle',
            [
                'label'   => esc_html__('Display', 'swp-shop'),
                'type'    => Controls_Manager::SELECT2,
                'options' => array(
                    'full' => esc_html__('Full Title', 'swp-shop'),
                    'excerpt'  => esc_html__('Excerpt', 'swp-shop'),
                ),
                'default' => 'full'

            ]
        );

        $this->add_control(
            'title_excerpt_length',
            [
                'label'   => esc_html__('Title Excerpt Length', 'swp-shop'),
                'type'    => Controls_Manager::TEXT,
                'default' => 3,
                'condition' => [
                    'dtitle' => 'excerpt'
                ]
            ]
        );

        $this->add_control(
            'titltag',
            [
                'label'   => esc_html__('Title Tag', 'swp-shop'),
                'type'    => Controls_Manager::SELECT,
                'options' => array(
                    'h1' => 'H1',
                    'h2' => 'H2',
                    'h3' => 'H3',
                    'h4' => 'H4',
                    'h5' => 'H5',
                    'h6' => 'H6',
                ),
                'default' => 'h5'

            ]
        );

        $this->end_controls_section(); // End title


        // other 
        $this->start_controls_section(
            'other_settings',
            [
                'label' => esc_html__('Other Settings', 'swp-shop'),
            ]
        );

        $this->add_control(
            'open-url',
            [
                'label'   => esc_html__('Where Open Product?', 'swp-shop'),
                'type'    => Controls_Manager::SELECT,
                'options' => array(
                    'same-window' => esc_html__('Same Window', 'swp-shop'),
                    'new-window' => esc_html__('New Window', 'swp-shop'),
                ),
                'default' => 'same-window'

            ]
        );

        $this->end_controls_section(); // End sub title

        //title style
        $this->start_controls_section(
            'title_style',
            [
                'label' => esc_html__('Title Style', 'swp-shop'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => esc_html__('Title Color', 'swp-shop'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-shop-single-inner .content-box .inner-title a' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'title_hover_color',
            [
                'label' => esc_html__('Title Hover Color', 'swp-shop'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-shop-single-inner .content-box .inner-title a:hover' => 'color: {{VALUE}}',
                ],
            ]
        );

        //title typography
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'           => 'title_typography',
                'label'          => esc_html__('Title Typography', 'swp-shop'),
                'selector'       => '{{WRAPPER}} .swp-shop-single-inner .content-box .inner-title a',
            ]
        );

        $this->end_controls_section();

        //price style
        $this->start_controls_section(
            'price_style',
            [
                'label' => esc_html__('Price Style', 'swp-shop'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'price_color',
            [
                'label' => esc_html__('Price Color', 'swp-shop'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .price,{{WRAPPER}} .woocommerce-Price-amount.amount' => 'color: {{VALUE}}',
                ],
            ]
        );

        //Price typography
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'           => 'price_typography',
                'label'          => esc_html__('Price Typography', 'swp-shop'),
                'selector'       => '{{WRAPPER}} .price,{{WRAPPER}} .woocommerce-Price-amount.amount',
            ]
        );

        $this->end_controls_section();

        //Other style
        $this->start_controls_section(
            'other_style',
            [
                'label' => esc_html__('Other ', 'swp-shop'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'badge_color',
            [
                'label' => esc_html__('Badge Color', 'swp-shop'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-badge-btn' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'badge_bg_color',
            [
                'label' => esc_html__('Badge Background Color', 'swp-shop'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-badge-btn' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'icon_color',
            [
                'label' => esc_html__('Icon Color', 'swp-shop'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-readmore-arrow' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'style' => ['style-1', 'style-2', 'style-3', 'style-4', 'style-5', 'style-6']
                ]
            ]
        );

        $this->add_control(
            'button_color',
            [
                'label' => esc_html__('Button Color', 'swp-shop'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-readmore-arrow-btn' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'style' =>  ['style-4', 'style-5', 'style-6']
                ]
            ]
        );

        $this->add_control(
            'button_hover_color',
            [
                'label' => esc_html__('Button Hover Color', 'swp-shop'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-readmore-arrow-btn:hover' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'style' =>  ['style-4', 'style-5', 'style-6']
                ]
            ]
        );

        $this->add_control(
            'button_hover_bg_color',
            [
                'label' => esc_html__('Button Hover Bg Color', 'swp-shop'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-readmore-arrow-btn:hover' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'style' =>  ['style-4', 'style-5', 'style-6']
                ]
            ]
        );

        //button typography
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'           => 'button_typography',
                'label'          => esc_html__('Button Typography', 'swp-shop'),
                'selector'       => '{{WRAPPER}} .swp-readmore-arrow-btn',
                'condition' => [
                    'style' =>  ['style-4', 'style-5', 'style-6']
                ]
            ]
        );

        $this->end_controls_section();

        //tab button style
        $this->start_controls_section(
            'tab_tab_button_style',
            [
                'label' => esc_html__('Tab Button Style', 'swp-shop'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'tab_button_color',
            [
                'label' => esc_html__('Button Color', 'swp-shop'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-tab-menu ul li a' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'tab_button_bg_color',
            [
                'label' => esc_html__('Button Background Color', 'swp-shop'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-tab-menu ul li a' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'tab_button_hover_bg_color',
            [
                'label' => esc_html__('Button Active/Hover Background Color', 'swp-shop'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-tab-menu ul li a.active,{{WRAPPER}} .swp-tab-menu ul li a:hover ' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        //Button typography
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'           => 'tab_button_typography',
                'label'          => esc_html__('Button Typography', 'swp-shop'),
                'selector'       => '{{WRAPPER}} .swp-tab-menu ul li a',
            ]
        );

        $this->end_controls_section();
    }

    protected function render()
    {

        $settings = $this->get_settings();

        include swp_shop_get_template('tab-one.php');
        include swp_shop_get_template('tab-two.php');
    }
}

plugin::instance()->widgets_manager->register(new Swp_Shop_Tab());
