<?php
if (!defined('ABSPATH')) {
  exit; // Exit if accessed directly.
}
/*
 * @package shop builder
 * since 1.0.0
 * 
*/


// image size
add_image_size('swp_shop_255x283', 255, 283, true);
add_image_size('swp_shop_260x290', 260, 290, false);
add_image_size('swp_shop_152x244', 152, 244, false);
add_image_size('swp_shop_540x728', 540, 728, false);



if (!function_exists('swp_shop_post_query')) {
  function swp_shop_post_query($post_type)
  {
    $post_list = get_posts(array(
      'post_type' => $post_type,
      'showposts' => -1,
    ));
    $posts = array();

    if (!empty($post_list) && !is_wp_error($post_list)) {
      foreach ($post_list as $post) {
        $options[$post->ID] = $post->post_title;
      }
      return $options;
    }
  }
}

if (!function_exists('swp_shop_post_category')) {
  //select category
  function swp_shop_post_category($terms = 'product_cat')
  {

    $terms = get_terms(array(
      'taxonomy'       => $terms,
      'hide_empty'     => false,
      'posts_per_page' => -1,
    ));

    $category_list = [];
    foreach ($terms as $post) {
      $category_list[$post->term_id] = [$post->name];
    }

    return $category_list;
  }
}

if (!function_exists('swp_shop_select_post')) {
  //select post 
  function swp_shop_select_post()
  {

    $args       = array('post_type' => 'product', 'posts_per_page' => -1);
    $post_lists = [];

    if ($postlists = get_posts($args)) {
      foreach ($postlists as $postlist) {
        (int) $post_lists[$postlist->ID] = $postlist->post_title;
      }
    } else {
      (int) $post_lists['0'] = esc_html__('No Post Found', 'swp-shop');
    }

    return $post_lists;
  }
}

if (!function_exists('swp_shop_get_cat_name')) {
  function swp_shop_get_cat_name($cat_id)
  {
    $cat_id   = (int) $cat_id;
    $category = get_term($cat_id, 'product_cat');

    if (!$category || is_wp_error($category)) {
      return '';
    }

    return $category->name;
  }
}

if (!function_exists('swp_shop_get_cat_slug')) {
  // category slug
  function swp_shop_get_cat_slug($cat_id)
  {
    $cat_id   = (int) $cat_id;
    $category = get_term($cat_id, 'product_cat');

    if (!$category || is_wp_error($category)) {
      return '';
    }

    return $category->slug;
  }
}


if (!function_exists('swp_shop_slug')) {
  function swp_shop_slug()
  {
    global $post;

    $swp_shop_link = get_permalink($post->ID);

    if (empty($swp_shop_link)) {
      return FALSE;
    } else {
      $swp_shop_link = str_replace(home_url('/'), '', $swp_shop_link);
      return $swp_shop_link;
    }
  }
}


if (!function_exists('swp_shop_get_template')) :
  function swp_shop_get_template($template_name = null)
  {
    $template_path = apply_filters('swp-shop-elementor/template-path', 'elementor-templates/');
    $template = locate_template($template_path . $template_name);
    if (!$template) {
      $template = SWP_SHOP_ELEMENTOR  . '/templates/' . $template_name;
    }
    if (file_exists($template)) {
      return $template;
    } else {
      return false;
    }
  }
endif;


if (!function_exists('swp_shop_display_percentage_on_sale_badge')) {
  function swp_shop_display_percentage_on_sale_badge()
  {
    global $product;

    if ($product->is_on_sale()) {
      if ($product->is_type('variable')) {
        // Get the variation prices
        $prices = $product->get_variation_prices();

        // Get the minimum regular price for the variable product
        $min_regular_price = min($prices['regular_price']);

        // Get the minimum sale price for the variable product
        $min_sale_price = min(array_filter($prices['sale_price']));

        $discount = round((($min_regular_price - $min_sale_price) / $min_regular_price) * 100);
      } else {
        $regular_price = $product->get_regular_price();
        if ($regular_price) :
          $sale_price = $product->get_sale_price();
          $discount = round((($regular_price - $sale_price) / $regular_price) * 100);
        endif;
      }
      if ($regular_price) :
        echo '<div class="swp-badge-btn">' . $discount . '% </div>';
      endif;
    }
  }
}



if (!function_exists('swp_shop_add_to_cart_button')) {
  function swp_shop_add_to_cart_button()
  {
    global $product;
    $swp_shop_ajax_cart_class = (get_option('woocommerce_enable_ajax_add_to_cart') == 'yes' ? 'swp_shop_ajax' : '');
    if ($product->is_type('variable')) {

      echo sprintf(
        '<a href="%s" class="%s">%s</a>',
        esc_url($product->add_to_cart_url()),
        esc_attr(implode(' ', array_filter(array(
          'button', 'product_type_' . $product->get_type(),
          'swp-readmore-arrow swp-add-to-cart'
        )))),
        '<i class="fas fa-shopping-cart"></i>'
      );
    } else {
      echo sprintf(
        '<a href="%s" data-quantity="1" class="%s" %s>%s</a>',
        esc_url($product->add_to_cart_url()),
        esc_attr(implode(' ', array_filter(array(
          'button', 'product_type_' . $product->get_type(),
          $product->is_purchasable() && $product->is_in_stock() ? 'add_to_cart_button' : '',
          $product->supports('ajax_add_to_cart') ? 'swp-readmore-arrow swp-add-to-cart ajax_add_to_cart' : 'swp-readmore-arrow swp-add-to-cart ',
          $swp_shop_ajax_cart_class
        )))),
        wc_implode_html_attributes(array(
          'data-product_id'  => $product->get_id(),
          'data-product_sku' => $product->get_sku(),
          'aria-label'       => $product->add_to_cart_description(),
          'rel'              => 'nofollow',
        )),
        '<i class="fas fa-shopping-cart"></i>'
      );
    }
  }
}


if (!function_exists('swp_shop_add_to_cart_text_button')) {
  function swp_shop_add_to_cart_text_button()
  {
    global $product;
    $swp_shop_ajax_cart_class = (get_option('woocommerce_enable_ajax_add_to_cart') == 'yes' ? 'swp_shop_ajax' : '');
    if ($product->is_type('variable')) {

      echo sprintf(
        '<a href="%s" class="%s">%s</a>',
        esc_url($product->add_to_cart_url()),
        esc_attr(implode(' ', array_filter(array(
          'button', 'product_type_' . $product->get_type(),
          'swp-readmore-arrow swp-add-to-cart swp-readmore-arrow-btn'
        )))),
        $product->add_to_cart_text()
      );
    } else {
      echo sprintf(
        '<a href="%s" data-quantity="1" class="%s" %s>%s</a>',
        esc_url($product->add_to_cart_url()),
        esc_attr(implode(' ', array_filter(array(
          'button', 'product_type_' . $product->get_type(),
          $product->is_purchasable() && $product->is_in_stock() ? 'add_to_cart_button' : '',
          $product->supports('ajax_add_to_cart') ? 'swp-readmore-arrow swp-add-to-cart ajax_add_to_cart swp-readmore-arrow-btn' : 'swp-readmore-arrow swp-add-to-cart swp-readmore-arrow-btn',
          $swp_shop_ajax_cart_class
        )))),
        wc_implode_html_attributes(array(
          'data-product_id'  => $product->get_id(),
          'data-product_sku' => $product->get_sku(),
          'aria-label'       => $product->add_to_cart_description(),
          'rel'              => 'nofollow',
        )),
        $product->add_to_cart_text()
      );
    }
  }
}


add_filter('woocommerce_add_to_cart_fragments', 'swp_shop_add_to_cart_message_ajax');
if (!function_exists('swp_shop_add_to_cart_message_ajax')) {
  function swp_shop_add_to_cart_message_ajax($fragments)
  {
    // Customize the message
    $message = '<div id="custom-message" class="custom-message"><i class="fas fa-check"></i>' . esc_html__('Product added successfully', 'swp-shop') . '</div>';
    $fragments['custom_message'] = $message;
    return $fragments;
  }
}

if (!function_exists('swp_shop_invert_formatted_sale_price')) {
  add_filter('woocommerce_format_sale_price', 'swp_shop_invert_formatted_sale_price', 10, 3);
  function swp_shop_invert_formatted_sale_price($price, $regular_price, $sale_price)
  {
    return '<ins>' . (is_numeric($sale_price) ? wc_price($sale_price) : $sale_price) . '</ins> <del>' . (is_numeric($regular_price) ? wc_price($regular_price) : $regular_price) . '</del>';
  }
}

if (!function_exists('swp_shop_body_classes')) {
  function swp_shop_body_classes($classes)
  {
    $classes[] = 'swp-shop-addon product';

    return $classes;
  }
  add_filter('body_class', 'swp_shop_body_classes');
}
